Aludel (aludel v0.1.18)

Copy Markdown View Source

Aludel keeps the contexts that define your domain and business logic.

Contexts are also responsible for managing your data, regardless if it comes from the database, an external API or others.