Ollama API adapter implementation.
Handles API communication with local Ollama models through the configured HTTP adapter.
Ollama doesn't require authentication, so we pass a random string as api_key to ReqLLM.
Ollama API adapter implementation.
Handles API communication with local Ollama models through the configured HTTP adapter.
Ollama doesn't require authentication, so we pass a random string as api_key to ReqLLM.