Schema for organizing prompts and test suites into projects.
Summary
Functions
Changeset for creating or updating a project.
Types
Functions
@spec changeset(t(), map()) :: Ecto.Changeset.t()
Changeset for creating or updating a project.
Schema for organizing prompts and test suites into projects.
Changeset for creating or updating a project.
@spec changeset(t(), map()) :: Ecto.Changeset.t()
Changeset for creating or updating a project.