Aludel.Web.Assets (aludel v0.1.18)

Copy Markdown View Source

Serves pre-compiled static assets for Aludel dashboard.

Assets are read at compile time and hashes are calculated dynamically from the file contents for cache busting.

Summary

Functions

current_hash(atom)