Domain-facing facade for document storage backends.
Test case documents are persisted through the configured storage adapter.
Summary
Functions
Persists document contents through the configured adapter and returns the adapter-specific storage key to save with the document row.
Types
Functions
@spec adapter() :: module()
@spec config() :: config()
@spec delete( String.t(), keyword() ) :: :ok | {:error, error_reason()}
@spec get( String.t(), keyword() ) :: {:ok, binary()} | {:error, error_reason()}
@spec put(String.t(), binary(), String.t()) :: {:ok, String.t()} | {:error, error_reason()}
Persists document contents through the configured adapter and returns the adapter-specific storage key to save with the document row.
@spec read(Aludel.Evals.TestCaseDocument.t()) :: {:ok, binary()} | {:error, error_reason()}
@spec storage_key(Ecto.UUID.t(), String.t()) :: String.t()